---
name: "📚 Documentation or README.md issue report"
about: "Report an issue in the project's documentation or README.md file."
title: ""
labels: "Documentation"


---
# **📚 Documentation Issue Report**

## **Describe the bug**
<!-- A clear and concise description of what the bug is. -->

*

---

### **To Reproduce**

<!-- Steps to reproduce the error:
(e.g.:)
1. Use x argument / navigate to
2. Fill this information
3. Go to...
4. See error -->

<!-- Write the steps here (add or remove as many steps as needed)-->

1.
2.
3.
4.

---

### **Media prove**
<!-- If applicable, add screenshots or videos to help explain your problem. -->

---

## **Describe the solution you'd like**
<!-- A clear and concise description of what you want to happen. -->

*

---

### **Additional context**
<!-- Add any other context or additional information about the problem here.-->

*

<!--📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛

Oh, hi there! 😄

To expedite issue processing, please search open and closed issues before submitting a new one.
Please read our Rules of Conduct at this repository's `.github/CODE_OF_CONDUCT.md`

📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛-->
